@@ -9,5 +9,6 @@ inclusionProb <- function(prob, size) {
     if(length(prob) == 0) return(numeric())
     if(length(size) == 0 || size == 0) return(rep.int(0, length(prob)))
     if(size < 0) stop("'size' must be a non-negative integer")
-    .Call("inclusionProb", prob, size, PACKAGE="simFrame")
+#    .Call("inclusionProb", prob, size, PACKAGE="simFrame")
+    .Call("R_inclusionProb", R_prob=prob, R_size=size, PACKAGE="simFrame")
 }
